Edwin A. Suominen, Patent Agent

## Background

Practice Specialty is in the preparation of patent applications and advocacy before the U.S. Patent Office.

Technical Emphasis is in electrical engineering, including RF, telecommunications, digital signal processing, analog and digital electronics, and computer software.

### EE Background

Bachelor of Science in Electrical Engineering, University of Washington, 1995.

Ten years in electrical technology and engineering. Centrally involved with the research and development of radio receivers using digital signal processing technology. Experience includes the design of a novel image-rejection receiver architecture, digital filters, multi-rate DSP downconverters, and algorithms for signal detection and analysis.

Experience with a wide variety of analog and digital electronic technology and several computer programming languages. Extensive participation in the preparation and prosecution of numerous pending patents related to electrical engineering work.

### Published Technical Works (Listed & linked by date of publication)

August 1999
Simplified High Frequency Broadband Tuner and Tuning Method. U.S. Patent 5,937,341

July 1999
Receiver with Analog and Digital Selectivity. U.S. Patent 5,926,513

March 1999
A Simple, Non-Invasive Probe for Reconstructing Signals Inside a DSP. IEEE Int'l Conference on Acoustic, Speech, and Signal Processing. Now issued as U.S. Patent 6,052,748. Click here to see information beyond the scope of the paper.

June 1998
Detection of a DSAT Sequence by Cross-Correlation. Virginia Tech. 8th Annual Symposium on Wireless Personal Communications.

1992 (600 KB)
A High Performance Vertical Antenna with No Radials. The ARRL Antenna Compendium, Vol. 3, pp.42-49

October 1988
Spiderweb Quad Antenna. QST Magazine, October 1988 issue, pp. 18-20

### Professional Associations

Institute of Electrical and Electronics Engineers (IEEE)
National Association of Patent Practitioners (NAPP)

### Language Skills

German, both conversational and written